Crate kcr_automation_kubensync_com

Crate kcr_automation_kubensync_com 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the automation.kubensync.com group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

automation.kubensync.com/v1alpha1

  • ManagedResource

Modules

v1alpha1